@@ -3,6 +3,7 @@ package migmigration
 import (
 	"time"
 
+	"github.com/deckarep/golang-set"
 	"github.com/go-logr/logr"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	"github.com/konveyor/mig-controller/pkg/compat"
@@ -41,6 +42,7 @@ const (
 	EnsureStagePodsFromTemplates    = "EnsureStagePodsFromTemplates"
 	EnsureStagePodsFromOrphanedPVCs = "EnsureStagePodsFromOrphanedPVCs"
 	StagePodsCreated                = "StagePodsCreated"
+	StagePodsFailed                 = "StagePodsFailed"
 	RestartRestic                   = "RestartRestic"
 	ResticRestarted                 = "ResticRestarted"
 	QuiesceApplications             = "QuiesceApplications"
@@ -225,7 +227,7 @@ type Task struct {
 	Owner           *migapi.MigMigration
 	PlanResources   *migapi.PlanResources
 	Annotations     map[string]string
-	BackupResources []string
+	BackupResources mapset.Set
 	Phase           string
 	Requeue         time.Duration
 	Itinerary       Itinerary
@@ -349,12 +351,16 @@ func (t *Task) Run() error {
 		t.Requeue = NoReQ
 		t.next()
 	case StagePodsCreated:
-		started, err := t.ensureStagePodsStarted()
+		report, err := t.ensureStagePodsStarted()
 		if err != nil {
 			log.Trace(err)
 			return err
 		}
-		if started {
+		if report.failed {
+			t.fail(StagePodsFailed, report.reasons)
+			break
+		}
+		if report.started {
 			t.next()
 		} else {
 			t.Requeue = NoReQ
@@ -673,11 +679,10 @@ func (t *Task) Run() error {
 			Durable:  true,
 		})
 		t.next()
-	// Out of tree states - needs to be triggered manually with t.fail(...)
-	case InitialBackupFailed, FinalRestoreFailed, StageBackupFailed, StageRestoreFailed:
+	case Completed:
+	default:
 		t.Requeue = NoReQ
 		t.next()
-	case Completed:
 	}
 
 	if t.Phase == Completed {
